# -*- coding: utf-8 -*-
from setuptools import setup

package_dir = \
{'': 'src'}

packages = \
['hrflow_connectors',
 'hrflow_connectors.connectors.adzuna',
 'hrflow_connectors.connectors.breezyhr',
 'hrflow_connectors.connectors.breezyhr.utils',
 'hrflow_connectors.connectors.bullhorn',
 'hrflow_connectors.connectors.bullhorn.utils',
 'hrflow_connectors.connectors.ceridian',
 'hrflow_connectors.connectors.greenhouse',
 'hrflow_connectors.connectors.hrflow',
 'hrflow_connectors.connectors.hrflow.warehouse',
 'hrflow_connectors.connectors.hubspot',
 'hrflow_connectors.connectors.poleemploi',
 'hrflow_connectors.connectors.recruitee',
 'hrflow_connectors.connectors.sapsuccessfactors',
 'hrflow_connectors.connectors.sapsuccessfactors.utils',
 'hrflow_connectors.connectors.smartrecruiters',
 'hrflow_connectors.connectors.talentsoft',
 'hrflow_connectors.connectors.teamtailor',
 'hrflow_connectors.connectors.waalaxy',
 'hrflow_connectors.connectors.workable',
 'hrflow_connectors.core',
 'hrflow_connectors.core.backend']

package_data = \
{'': ['*'],
 'hrflow_connectors.connectors.adzuna': ['docs/*'],
 'hrflow_connectors.connectors.breezyhr': ['docs/*'],
 'hrflow_connectors.connectors.bullhorn': ['docs/*'],
 'hrflow_connectors.connectors.ceridian': ['docs/*'],
 'hrflow_connectors.connectors.greenhouse': ['docs/*'],
 'hrflow_connectors.connectors.hubspot': ['docs/*'],
 'hrflow_connectors.connectors.poleemploi': ['docs/*'],
 'hrflow_connectors.connectors.recruitee': ['docs/*'],
 'hrflow_connectors.connectors.sapsuccessfactors': ['docs/*'],
 'hrflow_connectors.connectors.smartrecruiters': ['docs/*'],
 'hrflow_connectors.connectors.talentsoft': ['docs/*'],
 'hrflow_connectors.connectors.teamtailor': ['docs/*'],
 'hrflow_connectors.connectors.waalaxy': ['docs/*']}

install_requires = \
['Jinja2>=3.0.3,<4.0.0',
 'hrflow>=1.9.0,<2.0.0',
 'pydantic>=1.9.0,<2.0.0',
 'requests>=2.27.1,<3.0.0']

extras_require = \
{'s3': ['boto3>=1.24.66,<2.0.0']}

setup_kwargs = {
    'name': 'hrflow-connectors',
    'version': '2.0.0',
    'description': 'hrflow-connectors is an open source project created by HrFlow.ai to allow developers to connect easily HR ecosystem component.',
    'long_description': '<p align="center">\n  <a href="https://hrflow.ai">\n    <img alt="hrflow" src="https://img.riminder.net/logo-hrflow.svg" width="120" />\n  </a>\n</p>\n<h1 align="center">\n  HrFlow.ai connectors\n</h1>\n\n![GitHub Repo stars](https://img.shields.io/github/stars/Riminder/hrflow-connectors?style=social) ![](https://img.shields.io/github/v/release/Riminder/hrflow-connectors) ![](https://img.shields.io/github/license/Riminder/hrflow-connectors)\n\n\n<p align="center">\n  <a href="https://hrflow.ai">\n    <img alt="hrflow" src="https://hrflow-ai.imgix.net/corporate.svg"/>\n  </a>\n</p>\n\n<br/>\n\n## About HrFlow.ai\n\n**[HrFlow.ai](https://hrflow.ai/) is on a mission to make AI and data integration pipelines a commodity in the HR Industry:**\n  1. **Unify**: Link your Talent Data channels with a few clicks, so they can share data.\n  2. **Understand**: Leverage our AI solutions to process your Talent Data.\n  3. **Automate**: Sync data between your tools and build workflows that meet your business logic.\n\n**HrFlow-Connectors** is an open-source project created by HrFlow.ai to democratize Talent Data integration within the HR Tech landscape.\n\nWe invite developers to join us in our mission to bring AI and data integration to the HR industr, as a developper you can: \n\n- Create new connectors quickly and easily with our low-code connector approach and abstracted concepts\n- Contribute to the Connectors\' framework with your own code\n- Leverage our AI solutions to process your Talent Data\n- Sync data between your tools and build workflows that meet your business logic\n- Link your Talent Data channels with a few clicks, so they can share data\n\n📃 **More instructions are available in the Documentation section below** \n\n## :electric_plug: List of Connectors\n\n| Name 🔌 | Type 🔧  | Available 📦 | Release date 📅 | Last update 🔁 \n| - | - | - | - | - |\n| **ADP** | HCM Cloud | :hourglass: |   |  |\n| **ADENCLASSIFIEDS** | Job Board | :hourglass: |  |  |\n| **Adzuna** | Job Board | :heavy_check_mark: | *08/09/2022* | *12/01/2023* |\n| **Agefiph** | Job Board | :hourglass: |  |  |\n| **APEC** | Job Board | :hourglass: |  |  |\n| **Bullhorn** | ATS | :heavy_check_mark: | *26/01/2022* | *12/01/2023* |\n| **Breezy.hr** | ATS | :heavy_check_mark: | *19/01/2022* | *12/01/2023* |\n| **Cadreemploi** | Job Board | :hourglass: |  |  |\n| **Cegid (Meta4)** |  | :hourglass: |  |  |\n| **Ceridian** | HCM | :heavy_check_mark: | *19/01/2022* | *12/01/2023* |\n| **Cornerjob** | Job Board | :hourglass: |  |  |\n| **Cornerstone OnDemand** |  | :hourglass: |  |  |\n| **Crosstalent** | ATS | :wrench: | *19/01/2022* | |\n| **Digitalrecruiters** | ATS | :hourglass: |  |  |\n| **Distrijob** | Job Board | :hourglass: |  |  |\n| **Engagement Jeunes** | Job Board | :hourglass: |  |  |\n| **FashionJobs** | Job Board | :hourglass: |  |  |\n| **Fieldglass SAP** | Recruiting Software | :hourglass: |  |  |\n| **Flatchr** | ATS  | :wrench: | *21/04/2022* | |\n| **Glassdoor** | Job Board | :hourglass: |  |  |\n| **GoldenBees** | Job Board | :hourglass: |  |  |\n| **Greenhouse** | ATS  | :heavy_check_mark: | *19/01/2022* | *12/01/2023* |\n| **Handicap-Job** | Job Board | :hourglass: |  |  |\n| **HelloWork** | Job Board | :hourglass: |  |  |\n| **Hubspot** | CRM | :heavy_check_mark: | *27/10/2022* | *12/01/2023* |\n| **ICIMS** | ATS | :hourglass: |  |  |\n| **Indeed** | Job Board | :hourglass: |  |  |\n| **Inzojob** | Job Board | :hourglass: |  |  |\n| **Jobijoba** | Job Board | :hourglass: |  |  |\n| **Jobrapido** | Job Board | :hourglass: |  |  |\n| **JobTeaser** | Job Board | :hourglass: |  |  |\n| **Jobtransport** | Job Board | :hourglass: |  |  |\n| **Jobvitae** | Job Board | :hourglass: |  |  |\n| **Jobvite** |  | :hourglass: |  |  |\n| **Jooble** | Job Board | :hourglass: |  |  |\n| **Keljob** | Job Board | :hourglass: |  |  |\n| **Kronos (UKG)** | HCM Cloud | :hourglass: |  |  |\n| **Laponi** | Job Board | :hourglass: |  |  |\n|**Leboncoin** |     | :wrench: | *13/07/2022* | |\n| **LesJeudis** | Job Board | :hourglass: |  |  |\n| **Lever** | CRM-ATS | :hourglass:  |  |  |\n| **LinkedIn** | Job Board | :hourglass: |  |  |\n| **Mailchimp** | Marketing Tools | :hourglass: |  |  |\n| **Meteojob** | Job Board | :hourglass: |  |  |\n| **Microsoft Dynamics** | HCM Cloud | :hourglass: |  |  |\n| **Monster** | Job Board | :wrench: | *23/11/2022* | |\n| **Nuevoo** | Job Board | :hourglass: |  |  |\n| **Optioncarriere** | Job Board | :hourglass: |  |  |\n| **Oracle** | Cloud Apps | :hourglass: |  |  |\n| **Pole Emploi** | Job Board | :heavy_check_mark: |*15/07/2022* | *12/01/2023* |\n| **Recruitee** | ATS | :heavy_check_mark: | *30/10/2022* | *12/01/2023* |\n| **RecruitBox** |  | :hourglass: |  |  |\n| **RegionsJob** | Job Board | :hourglass: |  |  |\n| **SAPSuccessfactors** | Cloud Apps for HR | :heavy_check_mark: | *19/01/2022* | *12/01/2023* |\n| **Salesforce** | CRM-ATS | :hourglass: |  |  |\n| [**Smartrecruiters**](src/hrflow_connectors/connectors/smartrecruiters/) | ATS | :heavy_check_mark: | *21/03/2022* | *30/06/2022* |\n| **Staffme** | Job Board | :hourglass: |  |  |\n| **Staffsante** | Job Board | :hourglass: |  |  |\n| **Taleez** | ATS | :wrench: |*19/01/2022* | |\n| **Talentsoft** | HCM | :heavy_check_mark: | *19/04/2022* | *09/05/2022* |\n| **Talentlink** |  | :hourglass: |  |  |\n| **Teamtailor** | ATS | :heavy_check_mark: | *06/10/2022* | *12/01/2023* |\n| **Tekkit** | Job Board | :hourglass: |  |  |\n| **Turnover-IT** | Job Board | :hourglass: |  |  |\n| **Twilio** | Marketing Tools | :hourglass: |  |  |\n| **Ultimate Software (UKG)** |  | :hourglass: |  |  |\n| **Waalaxy** |  | :heavy_check_mark: |*18/11/2022* | *12/01/2023* |\n| **Workable** | HCM | :heavy_check_mark: | *27/09/2022* | *12/01/2023* |\n| **Welcome To The Jungle** | Job Board | :hourglass: |  |  |\n| **Wizbii** | Job Board | :hourglass: |  |  |\n| **Workday** | HCM Cloud | :heavy_check_mark: |  |  |\n| **XML** | Job Board | :wrench: |  |  |\n\n\n## \U0001fa84 Quickstart\n### What I can do?\nWith Hrflow Connector, you can **synchronize** and **process** multiple **HR data streams** in just a few lines of code.\n\nYou can do any kind of data transfer between HrFlow.ai and external destinations :\n* Pull jobs : `External Job flow` :arrow_right: ***`Hrflow.ai Board`***\n* Pull profiles : `External Profile flow` :arrow_right: ***`Hrflow.ai Source`***\n* Push job : ***`Hrflow.ai Board`*** :arrow_right: `External destination`\n* Push profile : ***`Hrflow.ai Source`*** :arrow_right: `External destination`\n\nThe features offered by this package:\n* **Synchronize an entire data** stream with a ready-to-use solution\n*  **Synchronize only certain data** in a stream meeting a condition defined by you : [`logics`](DOCUMENTATION.md#logics)\n* **Format the data as you wish** or use the default formatting that we propose adapted to each connector : [`format`](DOCUMENTATION.md#format)\n* **Leverage the provider *Hrflow.ai\'s ** Job and Profile Warehouse * with a many available options like [`hydrate_with_parsing`](src/hrflow_connectors/connectors/hrflow/warehouse.py#L42) or [`update_content`](src/hrflow_connectors/connectors/hrflow/warehouse.py#L39)\n\n### How to use a connector ?\n**Prerequisites**\n* [✨ Create a Workspace](https://hrflow.ai/signup/)\n* [🔑 Get your API Key](https://developers.hrflow.ai/docs/api-authentification)\n\n1. **`pip install hrflow-connectors`**\n2. Pick the connector you would like to use. Let\'s say it\'s **SmartRecruiters**\n3. Navigate to the connector\'s _README_. That would be [here](src/hrflow_connectors/connectors/smartrecruiters/README.md) for **SmartRecruiters**\n4. Choose from the available actions the one you would like to use\n5. Navigate to the action\'s documentation to find ready for copy/paste integration code\n\n:checkered_flag: **TADA! You have just used your first connector.**\n\n\n## 📖 Documentation\nTo find out **more about the HrFlow.ai Connectors framework** take a look at the [📖 documentation](DOCUMENTATION.md).\n\n## :bulb: Contributions\n\nPlease feel free to contribute to the quality of this content by\nsubmitting PRs for improvements to code, architecture, etc.\n\nAny contributions you make to this effort are of course greatly\nappreciated.\n\n👉 **To find out more about how to proceed, the rules and conventions to follow, read carefully [`CONTRIBUTING.md`](CONTRIBUTING.md).**\n\n## 🔗 Resources\n* Our Developers documentation : https://developers.hrflow.ai/\n* Our API list (Parsing, Revealing, Embedding, Searching, Scoring, Reasoning) : https://www.hrflow.ai/api\n* Our cool demos labs : https://labs.hrflow.ai\n\n## :page_with_curl: License\n\nSee the [`LICENSE`](LICENSE) file for licensing information.\n',
    'author': 'HrFlow.ai',
    'author_email': 'support+hrflow_connectors@hrflow.ai',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/Riminder/hrflow-connectors',
    'package_dir': package_dir,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'extras_require': extras_require,
    'python_requires': '==3.10.5',
}


setup(**setup_kwargs)



from hrflow_connectors.connectors.hrflow.warehouse.job import HrFlowJobWarehouse  # noqa
from hrflow_connectors.connectors.hrflow.warehouse.profile import (  # noqa
    HrFlowProfileParsingWarehouse,
    HrFlowProfileWarehouse,
)



import datetime
import typing as t
from enum import Enum, IntEnum
from typing import Any, List

from pydantic import BaseModel, Field, validator

POLE_EMPLOI_REFERENCES_ENDPOINT = (
    "https://api.emploi-store.fr/partenaire/offresdemploi/v2/referentiel/"
)


def validate_date(value: Any) -> Any:
    try:
        datetime.date.fromisoformat(value)
        return value
    except ValueError:
        raise ValueError(
            f"Invalid time format given {value}, expected format ISO 8601 format"
            " ISO-8601 (YYYY-MM-DDTHH:MM:SSZ)"
        )


class JobLocation(BaseModel):
    libelle: str
    latitude: float
    longitude: float
    codepostal: str
    commune: str = Field(
        description=(
            "INSEE code of the commune"
            "A GET request for the list of accepted choices from the Offres"
            " d'emploi API"
            "to this endpoint :"
            f" {POLE_EMPLOI_REFERENCES_ENDPOINT}communes"
        ),
    )


class Entreprise(BaseModel):
    nom: t.Optional[str]
    description: t.Optional[str]
    logo: t.Optional[str]
    url: t.Optional[str]
    entrepriseAdaptee: bool


class Partner(BaseModel):
    nom: str
    url: str
    logo: str


class OfferOriginTag(IntEnum):
    POLE_EMPLOI = 1
    PARTNER = 2


class OfferOrigin(BaseModel):
    origine: OfferOriginTag
    urlOrigine: t.Optional[str]
    partenaires: List[Partner]


class ExperienceRequirement(str, Enum):
    BEGINNER_ACCEPTED = "D"
    EXPERIENCE_DESIRED = "S"
    EXPERIENCE_REQUIRED = "E"


class Exigence(Enum):
    REQUIRED = "E"
    DESIRED = "S"


class Formation(BaseModel):
    domaineLibelle: str
    niveauLibelle: str = Field(
        description=(
            "Label of the level of the education required"
            "A GET request for the list of accepted choices from the Offres"
            " d'emploi API"
            "to this endpoint :"
            f" {POLE_EMPLOI_REFERENCES_ENDPOINT}referentiel/niveauxFormations"
        ),
    )
    commentaire: str
    exigence: Exigence


class Langue(BaseModel):
    libelle: str = Field(
        description=(
            "Language label"
            "A GET request for the list of accepted choices from the Offres"
            " d'emploi API"
            "to this endpoint :"
            f" {POLE_EMPLOI_REFERENCES_ENDPOINT}referentiel/langues"
        ),
    )
    exigence: t.Optional[Exigence]


class Permis(BaseModel):
    libelle: str = Field(
        description=(
            "requested license"
            "A GET request for the list of accepted choices from the Offres"
            " d'emploi API"
            "to this endpoint :"
            f" {POLE_EMPLOI_REFERENCES_ENDPOINT}referentiel/permis"
        ),
    )
    exigence: t.Optional[Exigence]


class Competence(BaseModel):
    code: str
    libelle: str
    exigence: t.Optional[Exigence]


class Salaire(BaseModel):
    libelle: t.Optional[str]
    commentaire: t.Optional[str]
    complement1: t.Optional[str]
    complement2: t.Optional[str]


class Contact(BaseModel):
    nom: t.Optional[str]
    coordonnees1: t.Optional[str]
    coordonnees2: t.Optional[str]
    coordonnees3: t.Optional[str]
    telephone: t.Optional[str]
    courriel: t.Optional[str]
    commentaire: t.Optional[str]
    urlRecruteur: t.Optional[str]
    urlPostulation: t.Optional[str]


class Agence(BaseModel):
    telephone: t.Optional[str]
    courriel: t.Optional[str]


class QualificationCode(str, Enum):
    MANOEUVRE = "1"
    SPECIALIZED_WORKER = "2"
    QUALIFIED_WORKER_P1_P2 = "3"
    QUALIFIED_WORKER_P3_P4_OHQ = "4"
    UNQUALIFIED_EMPLOYEE = "5"
    QUALIFIED_EMPLOYEE = "6"
    TECHNICIAN = "7"
    SUPERVISORY_AGENT = "8"
    EXECUTIVE = "9"


class QualificationLibelle(str, Enum):
    MANOEUVRE = "Manœuvre"
    SPECIALIZED_WORKER = "Ouvrier spécialisé"
    QUALIFIED_WORKER_P1_P2 = "Ouvrier qualifié (P1, P2)"
    QUALIFIED_WORKER_P3_P4_OHQ = "Ouvrier qualifié (P3, P4, OHQ)"
    UNQUALIFIED_EMPLOYEE = "Employé non qualifié"
    QUALIFIED_EMPLOYEE = "Employé qualifié"
    TECHNICIAN = "Technicien"
    SUPERVISORY_AGENT = "Agent de maîtrise"
    EXECUTIVE = "Cadre"


class QualitePro(BaseModel):
    libelle: t.Optional[str]
    description: t.Optional[str]


class PoleEmploiJobOffer(BaseModel):
    id: int
    intitule: str
    description: str
    dateCreation: t.Optional[str]
    dateActualisation: t.Optional[str]
    lieuTravail: t.Optional[JobLocation]
    romeCode: t.Optional[str] = Field(
        description=(
            "ROME code of the profession"
            "A GET request for the list of accepted choices from the Offres"
            " d'emploi API"
            "to this endpoint :"
            f" {POLE_EMPLOI_REFERENCES_ENDPOINT}metiers"
        ),
    )
    romeLibelle: t.Optional[str]
    appellationLibelle: t.Optional[str] = Field(
        description=(
            "Code of the appellation"
            "A GET request for the list of accepted choices from the Offres"
            " d'emploi API"
            "to this endpoint :"
            f" {POLE_EMPLOI_REFERENCES_ENDPOINT}appellations"
        ),
    )
    entreprise: t.Optional[Entreprise]
    typeContrat: t.Optional[str] = Field(
        description=(
            "Contract type code"
            "A GET request for the list of accepted choices from the Offres"
            " d'emploi API"
            "to this endpoint :"
            f" {POLE_EMPLOI_REFERENCES_ENDPOINT}typesContrats"
        ),
    )
    typeContratLibelle: t.Optional[str] = Field(
        description=(
            "Contract type label"
            "Example : CDI,CDD"
            "A GET request for the list of accepted choices from the Offres"
            " d'emploi API"
            "to this endpoint :"
            f" {POLE_EMPLOI_REFERENCES_ENDPOINT}typesContrats"
        ),
    )
    natureContrat: t.Optional[str] = Field(
        description=(
            "Code of the nature of contract"
            "A GET request for the list of accepted choices from the Offres"
            " d'emploi API"
            "to this endpoint :"
            f" {POLE_EMPLOI_REFERENCES_ENDPOINT}naturesContrats"
        ),
    )
    origineOffre: t.Optional[OfferOrigin]
    offresManqueCandidats: t.Optional[bool]
    experienceExige: t.Optional[ExperienceRequirement]
    experienceLibelle: t.Optional[str]
    experienceCommentaire: t.Optional[str]
    formations: t.Optional[List[Formation]]
    langues: t.Optional[List[Langue]]
    permis: t.Optional[List[Permis]]
    outilsBureautiques: t.Optional[str]
    competences: t.Optional[List[Competence]]
    salaire: t.Optional[Salaire]
    dureeTravailLibelle: t.Optional[str]
    dureeTravailLibelleConverti: t.Optional[str]
    complementExercice: t.Optional[str]
    conditionExercice: t.Optional[str]
    alternance: t.Optional[bool]
    contact: t.Optional[Contact]
    agence: t.Optional[Agence]
    nombrePostes: t.Optional[int]
    accessibleTH: t.Optional[bool]
    deplacementCode: t.Optional[str]
    deplacementLibelle: t.Optional[str]
    qualificationCode: t.Optional[QualificationCode]
    qualificationLibelle: t.Optional[QualificationLibelle]
    secteurActivite: t.Optional[str] = Field(
        description=(
            "NAF codes for sectors of activity. It is possible to specify two NAF codes"
            " by separating them with a comma in the character string."
            "Example : 01,02"
            "A GET request for the list of accepted choices from the Offres"
            " d'emploi API"
            "to this endpoint :"
            f" {POLE_EMPLOI_REFERENCES_ENDPOINT}secteursActivites"
        ),
    )
    secteurActiviteLibelle: t.Optional[str] = Field(
        description=(
            "Sector of activitylabel"
            "A GET request for the list of accepted choices from the Offres"
            " d'emploi API"
            "to this endpoint :"
            f" {POLE_EMPLOI_REFERENCES_ENDPOINT}secteursActivites"
        ),
    )
    qualitesProfessionnelles: t.Optional[List[QualitePro]]

    # validators
    _validate_dateCreation = validator("dateCreation", allow_reuse=True)(validate_date)
    _validate_dateActualisation = validator("dateActualisation", allow_reuse=True)(
        validate_date
    )



import json
import typing as t
from io import BytesIO
from logging import LoggerAdapter
from zipfile import ZipFile

import requests
from pydantic import Field

from hrflow_connectors.core import (
    DataType,
    FieldType,
    ParametersModel,
    ReadMode,
    Warehouse,
    WarehouseReadAction,
)

GRANT_TYPE = "client_credentials"
TOKEN_SCOPE = "MatchingIndexation"
LIMIT = 100


class ReadProfilesParameters(ParametersModel):
    client_id: str = Field(
        ...,
        description="Client ID used to access TalentSoft API",
        repr=False,
        field_type=FieldType.Auth,
    )
    client_secret: str = Field(
        ...,
        description="Client Secret used to access TalentSoft API",
        repr=False,
        field_type=FieldType.Auth,
    )
    client_url: str = Field(
        ...,
        description="URL of TalentSoft client integration",
        field_type=FieldType.Other,
    )
    filter: t.Optional[str] = Field(
        None,
        description=(
            "Filter to apply when reading profiles. See documentation at"
            " https://developers.cegid.com/api-details#api=cegid-talentsoft-recruiting-"
            "matchingindexation&operation=api-exports-v1-candidates-get ."
            " Examples : By id Single Item 'id::_TS-00001'; By id Multiple"
            " Items 'id::_TS-00001,_TS-00002'; By email"
            " 'email::john.doe@company.corp'; By updateDate updated before the 10th"
            " of June 2019 'updateDate:lt:2019-06-10'; By chronoNumber greater than"
            " 108921  'chronoNumber:gt:108921'"
        ),
        field_type=FieldType.QueryParam,
    )
    fileId: t.Optional[str] = Field(
        description=(
            "If provided only the attachment matching with fileId is left in"
            " 'attachments'. If not found all attachments are left."
        ),
        field_type=FieldType.QueryParam,
    )
    only_resume: bool = Field(
        False,
        description="If enabled only resume attachments are returned",
        field_type=FieldType.QueryParam,
    )


class ReadJobsParameters(ParametersModel):
    client_id: str = Field(
        ...,
        description="Client ID used to access TalentSoft API",
        repr=False,
        field_type=FieldType.Auth,
    )
    client_secret: str = Field(
        ...,
        description="Client Secret used to access TalentSoft API",
        repr=False,
        field_type=FieldType.Auth,
    )
    client_url: str = Field(
        ...,
        description="URL of TalentSoft client integration",
        field_type=FieldType.Other,
    )
    q: t.Optional[str] = Field(
        None,
        description="Query search to get vacancies",
        field_type=FieldType.QueryParam,
    )
    filter: t.Optional[str] = Field(
        None,
        description=(
            "Filter to apply when reading vacancies. See documentation at"
            " https://developers.cegid.com/api-details#api=cegid-talentsoft-recruiting"
            "-matchingindexation&operation=api-exports-v1-vacancies-get"
            " . . You can filter by **chronoNumber**, **updateDate**, **reference**"
            " **vacancyStatus**, **clientVacancyStatus**, **publicationMedia** "
            " **publishedOnTheMedia**. Examples : By reference Single Item"
            " 'reference::2019-01'; By reference Multiple Items"
            " 'reference::2019-01,2019-02,2019-03';  By updateDate updated before the"
            " 10th of June 2019 'updateDate:lt:2019-06-10'; By chronoNumber greater"
            " than 108921  'chronoNumber:gt:108921' . "
        ),
        field_type=FieldType.QueryParam,
    )


def get_talentsoft_auth_token(
    client_url: str, client_id: str, client_secret: str
) -> str:
    response = requests.post(
        "{}/api/token".format(client_url),
        headers={
            "Content-Type": "application/x-www-form-urlencoded",
        },
        data=dict(
            grant_type=GRANT_TYPE,
            scope=TOKEN_SCOPE,
            client_id=client_id,
            client_secret=client_secret,
        ),
    )
    if not response.ok:
        raise Exception(
            "Failed to get authentication token with error={}".format(response.text)
        )
    try:
        return response.json()["access_token"]
    except (KeyError, requests.exceptions.JSONDecodeError) as e:
        raise Exception(
            "Failed to get token from response with error={}".format(repr(e))
        )


def read_jobs(
    adapter: LoggerAdapter,
    parameters: ReadProfilesParameters,
    read_mode: t.Optional[ReadMode] = None,
    read_from: t.Optional[str] = None,
) -> t.Iterable[t.Dict]:
    token = get_talentsoft_auth_token(
        client_url=parameters.client_url,
        client_id=parameters.client_id,
        client_secret=parameters.client_secret,
    )
    params = dict(offset=0, limit=LIMIT)
    if parameters.filter:
        params["filter"] = parameters.filter
    if parameters.q:
        params["q"] = parameters.q

    while True:
        response = requests.get(
            "{}/api/exports/v1/vacancies".format(parameters.client_url),
            params=params,
            headers={
                "Authorization": "bearer {}".format(token),
            },
        )
        if not response.ok:
            raise Exception(
                "Failed to fetch jobs with params={} from TalentSoft with"
                " error={}".format(params, response.text)
            )
        if response.headers.get("Content-Length") == 0 or not response.content:
            if params["offset"] == 0:
                adapter.info(
                    "No jobs found with params={} text={} headers={}".format(
                        params, response.text, response.headers
                    )
                )
            return

        data = response.content
        while data:
            read_up_to = int.from_bytes(data[0:4], byteorder="little")
            zip_data = ZipFile(BytesIO(data[4 : 4 + read_up_to]))
            job = json.loads(zip_data.read("offerdetail").decode())["offerDetail"]
            yield job
            data = data[4 + read_up_to :]
        params["offset"] += LIMIT


def read_profiles(
    adapter: LoggerAdapter,
    parameters: ReadProfilesParameters,
    read_mode: t.Optional[ReadMode] = None,
    read_from: t.Optional[str] = None,
) -> t.Iterable[t.Dict]:
    token = get_talentsoft_auth_token(
        client_url=parameters.client_url,
        client_id=parameters.client_id,
        client_secret=parameters.client_secret,
    )
    params = dict(offset=0, limit=LIMIT)
    if parameters.filter:
        params["filter"] = parameters.filter
    if parameters.only_resume:
        params["attachmenttype"] = "resume"

    while True:
        response = requests.get(
            "{}/api/exports/v1/candidates".format(parameters.client_url),
            params=params,
            headers={
                "Authorization": "bearer {}".format(token),
            },
        )
        if not response.ok:
            raise Exception(
                "Failed to fetch candidates with params={} from TalentSoft with"
                " error={}".format(params, response.text)
            )
        if response.headers.get("Content-Length") == 0 or not response.content:
            if params["offset"] == 0:
                adapter.info(
                    "No profiles found with params={} text={} headers={}".format(
                        params, response.text, response.headers
                    )
                )
            return

        data = response.content
        while data:
            read_up_to = int.from_bytes(data[0:4], byteorder="little")
            zip_data = ZipFile(BytesIO(data[4 : 4 + read_up_to]))
            candidate = json.loads(zip_data.read("applicantdetail").decode())
            for attachment in candidate["attachments"]:
                attachment["raw"] = zip_data.read(attachment["id"])
            if parameters.fileId is not None:
                found = next(
                    (
                        attachment
                        for attachment in candidate["attachments"]
                        if attachment["id"] == parameters.fileId
                    ),
                    None,
                )
                if found:
                    candidate["attachments"] = [found]
            yield candidate
            data = data[4 + read_up_to :]
        params["offset"] += LIMIT


TalentSoftProfilesWarehouse = Warehouse(
    name="TalentSoft Profiles",
    data_type=DataType.profile,
    read=WarehouseReadAction(
        parameters=ReadProfilesParameters,
        function=read_profiles,
    ),
)


TalentSoftJobsWarehouse = Warehouse(
    name="TalentSoft Jobs",
    data_type=DataType.job,
    read=WarehouseReadAction(
        parameters=ReadJobsParameters,
        function=read_jobs,
    ),
)



import re


def remove_html_tags(text: str) -> str:
    """
    Remove all HTML tags in a string
    Args:
        text (str): text to clean
    Returns:
        str: cleaned text (without HTML tags)
    """
    return re.sub("<[^<]+?>", "", text)



import typing as t

from hrflow_connectors.connectors.hrflow.warehouse import HrFlowJobWarehouse
from hrflow_connectors.connectors.poleemploi.warehouse import PoleEmploiJobWarehouse
from hrflow_connectors.core import (
    BaseActionParameters,
    Connector,
    ConnectorAction,
    WorkflowType,
)


def get_job_location(pole_emploi_location: t.Union[t.Dict, None]) -> t.Dict:
    if pole_emploi_location is None:
        return dict(lat=None, lng=None, text="")

    lat = pole_emploi_location.get("latitude")
    lat = float(lat) if lat is not None else lat

    lng = pole_emploi_location.get("longitude")
    lng = float(lng) if lng is not None else lng

    return dict(
        lat=lat,
        lng=lng,
        text=" ".join(
            [
                pole_emploi_location.get(field)
                for field in ["libelle", "codePostal"]
                if pole_emploi_location.get(field)
            ]
        ),
    )


def get_sections(pole_emploi_job: t.Dict) -> t.List[t.Dict]:
    sections = []
    if (
        "entreprise" in pole_emploi_job
        and "description" in pole_emploi_job["entreprise"]
    ):
        sections.append(
            dict(
                name="pole_emploi_company_description",
                title="Company Description",
                description=pole_emploi_job["entreprise"]["description"],
            )
        )
    return sections


def get_tags(pole_emploi_job: t.Dict) -> t.List[t.Dict]:
    job = pole_emploi_job
    contact = job.get("contact", {})
    salary = job.get("salaire", {})
    tags = []

    t = lambda name, value: dict(name=name, value=value)
    tags = [
        t("pole_emploi_romeCode", job.get("romeCode")),
        t("pole_emploi_romeLibelle", job.get("romeLibelle")),
        t("pole_emploi_appellationLibelle", job.get("appellationLibelle")),
        t("pole_emploi_contractNature", job.get("natureContrat")),
        t("pole_emploi_contractType", job.get("typeContratLibelle")),
        t("pole_emploi_experience", job.get("experienceLibelle")),
        t("pole_emploi_salary", salary.get("libelle")),
        t("pole_emploi_working_hours", job.get("dureeTravailLibelle")),
        t("pole_emploi_qualification", job.get("qualificationLibelle")),
        t("pole_emploi_secteurActivite", job.get("secteurActiviteLibelle")),
        t("pole_emploi_contact-name", contact.get("nom")),
        t("pole_emploi_contact-email", contact.get("courriel")),
        t("pole_emploi_contact-phone", contact.get("telephone")),
    ]
    return tags


def format_job(
    pole_emploi_job: t.Dict,
) -> t.Dict:
    job = dict(
        name=pole_emploi_job.get("intitule"),
        reference=pole_emploi_job.get("id"),
        created_at=pole_emploi_job.get("dateCreation"),
        updated_at=pole_emploi_job.get("dateActualisation"),
        location=get_job_location(pole_emploi_job.get("lieuTravail")),
        url=None,
        summary=pole_emploi_job.get("description"),
        sections=get_sections(pole_emploi_job),
        tags=get_tags(pole_emploi_job),
    )
    return job


DESCRIPTION = (
    "Thanks to the Job Offers API, you can access all the job offers available on the"
    " Pôle emploi website at any time and in real time."
)

PoleEmploi = Connector(
    name="PoleEmploi",
    description=DESCRIPTION,
    url="https://www.pole-emploi.fr/",
    actions=[
        ConnectorAction(
            name="pull_jobs",
            trigger_type=WorkflowType.pull,
            description=(
                "Retrieves jobs via the ***Offres d'emploi v2*** API from the Pôle"
                " emploi website based on selection criteria set in the and send them"
                " to a ***Hrflow.ai Board***."
            ),
            parameters=BaseActionParameters.with_defaults(
                "ReadJobsActionParameters", format=format_job
            ),
            origin=PoleEmploiJobWarehouse,
            target=HrFlowJobWarehouse,
        ),
    ],
)
